==> schedwisrv-0.1.4.tar.gz: schedwisrv-0.1.4/src/module.h <==
/* Schedwi
   Copyright (C) 2007 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* module.h -- Modules management functions */

#ifndef _MODULE_H
#define _MODULE_H

#include <schedwi.h>
#include <schedwi_jobtree.h>
#include <job_status_state.h>


/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int module_init OF(());
extern void module_exit OF(());
extern int module_path OF((const char *path));
extern int module_load OF((const char *file));
extern int module_conf OF((	const char *name,
				const char *key, const char *value));
extern int module_status OF((	int workload,
				const schedwi_jobtree_node_ptr job,
				job_status_state old_status,
				job_status_state new_status));
extern int module_check OF((	int workload,
				const schedwi_jobtree_node_ptr job));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* module.h */

/*-----------------============== End Of File ==============-----------------*/

==> schedwisrv-0.1.7.tar.gz: schedwisrv-0.1.7/src/module.h <==
/* Schedwi
   Copyright (C) 2007-2015 Herve Quatremain

   This file is part of Schedwi.

   Schedwi is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   Schedwi is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/* module.h -- Modules management functions */

#ifndef _MODULE_H
#define _MODULE_H

#include <schedwi.h>

#if HAVE_TIME_H
#include <time.h>
#endif

#include <result_mgnt.h>
#include <job_status_node.h>
#include <job_status_state.h>


/* Allow the use in C++ code.  */
#ifdef __cplusplus
extern "C" {
#endif

extern int module_init OF(());
extern void module_exit OF(());
extern int module_path OF((const char *path));
extern int module_load OF((const char *file));
extern int module_conf OF((	const char *name,
				const char *key, const char *value));
extern int module_status OF((	const result_t * const result,
				const char *job_name_with_path,
				job_status_state new_state,
				job_status_state previous_state,
				long int duration, int retry_num,
				const char *status_message));
extern int module_check OF((	const job_status_node_ptr const job_details,
				time_t start_time,
				short int start_limit));

#ifdef __cplusplus
}
#endif  /* C++ */

#endif /* module.h */

/*-----------------============== End Of File ==============-----------------*/
